using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using DevExpress.XtraPrinting;
using DevExpress.XtraGrid;
using DevExpress.XtraBars.Ribbon;
using DevExpress.XtraBars;

namespace TestLocalization {
    /// <summary>
    /// Summary description for Form1.
    /// </summary>
    public partial class FormMain : RibbonForm {
        public FormMain() {
            //
            // Required for Windows Form Designer support
            //
            InitializeComponent();

            //
            // TODO: Add any constructor code after InitializeComponent call
            //
        }

        private void OnChildFormClosing(object sender, CancelEventArgs e) {
            Form form = (Form)sender;
            ((IDisposable)form.Tag).Dispose();
            form.Tag = null;
            form.FormClosing -= OnChildFormClosing;
        }

        private void OnShowChartsItemClick(object sender, ItemClickEventArgs e) {
            new FormChart() { MdiParent = this }.Show();
        }

        private void OnShowGridButtonClick(object sender, ItemClickEventArgs e) {
            new FormGrid() { MdiParent = this }.Show();
        }

        private void OnShowPivotGridButtonClick(object sender, ItemClickEventArgs e) {
            new FormPivot() { MdiParent = this }.Show();
        }

        private void OnShowRichEditButtonClick(object sender, ItemClickEventArgs e) {
            new FormRichEdit() { MdiParent = this }.Show();
        }

        private void OnShowSchedulerButtonClick(object sender, ItemClickEventArgs e) {
            new FormScheduler() { MdiParent = this }.Show();
        }

        private void OnShowTreeListButtonClick(object sender, ItemClickEventArgs e) {
            new FormTreeList() { MdiParent = this }.Show();
        }

        private void OnShowWizardButtonClick(object sender, ItemClickEventArgs e) {
            using (FormWizard wizard = new FormWizard()) {
                wizard.ShowDialog();
            }
        }

        private void OnShowGaugesButtonClick(object sender, ItemClickEventArgs e) {
            new FormGauge() { MdiParent = this }.Show();
        }

        private void OnShowLayoutEditorsSpellCheckerButtonClick(object sender, ItemClickEventArgs e) {
            new FormLayoutAndEditors() { MdiParent = this }.Show();
        }

        private void OnShowPrintPreviewBarsButtonClick(object sender, ItemClickEventArgs e) {
            DevExpress.XtraPrinting.Preview.PrintPreviewFormEx form = new DevExpress.XtraPrinting.Preview.PrintPreviewFormEx();
            XtraReport1 report = new XtraReport1();
            form.Tag = report;
            form.FormClosing += OnChildFormClosing;
            form.PrintingSystem = report.PrintingSystem;
            report.CreateDocument();
            form.MdiParent = this;
            form.Show();
        }

        private void OnShowPrintPreviewRibbonButtonClick(object sender, ItemClickEventArgs e) {
            DevExpress.XtraPrinting.Preview.PrintPreviewRibbonFormEx form = new DevExpress.XtraPrinting.Preview.PrintPreviewRibbonFormEx();
            GridControl grid = new GridControl();
            PrintingSystem ps = new PrintingSystem();
            form.PrintControl.PrintingSystem = ps;
            PrintableComponentLink link = new PrintableComponentLink(ps);
            grid.Parent = form;
            grid.ForceInitialize();
            new DevExpress.XtraGrid.Design.XViewsPrinting(grid);
            DevExpress.XtraGrid.Views.Grid.GridView view = (DevExpress.XtraGrid.Views.Grid.GridView)grid.MainView;
            view.GroupSummary.Add(DevExpress.Data.SummaryItemType.Count, "");
            view.OptionsView.ShowFooter = true;
            view.ActiveFilterCriteria = DevExpress.Data.Filtering.CriteriaOperator.Parse("[Discontinued] = False");
            link.Component = grid;
            link.CreateDocument();
            form.MdiParent = this;
            form.Show();
        }

        private void OnShowPrintPreviewReportDesignerButtonClick(object sender, ItemClickEventArgs e) {
            new XtraReport1().ShowDesigner();
        }

        private void OnRibbonMerge(object sender, RibbonMergeEventArgs e) {
            Ribbon.SelectedPage = e.MergedChild.SelectedPage;
        }
    }
}
